@@ -39,7 +39,7 @@ from barman.exceptions import (AbortedRetryHookScript,
                                CompressionIncompatibility, SshCommandException,
                                UnknownBackupIdException)
 from barman.hooks import HookScriptRunner, RetryHookScriptRunner
-from barman.infofile import BackupInfo, WalFileInfo
+from barman.infofile import BackupInfo, LocalBackupInfo, WalFileInfo
 from barman.lockfile import ServerBackupSyncLock
 from barman.recovery_executor import RecoveryExecutor
 from barman.remote_status import RemoteStatusMixin
@@ -113,7 +113,7 @@ class BackupManager(RemoteStatusMixin):
         # Load all the backups from disk reading the backup.info files
         for filename in glob("%s/*/backup.info" %
                              self.config.basebackups_directory):
-            backup = BackupInfo(self.server, filename)
+            backup = LocalBackupInfo(self.server, filename)
             self._backup_cache[backup.backup_id] = backup
 
     def backup_cache_add(self, backup_info):
@@ -174,7 +174,7 @@ class BackupManager(RemoteStatusMixin):
         """
         if not isinstance(status_filter, tuple):
             status_filter = tuple(status_filter)
-        backup = BackupInfo(self.server, backup_id=backup_id)
+        backup = LocalBackupInfo(self.server, backup_id=backup_id)
         available_backups = self.get_available_backups(
             status_filter + (backup.status,))
         ids = sorted(available_backups.keys())
@@ -199,7 +199,7 @@ class BackupManager(RemoteStatusMixin):
         """
         if not isinstance(status_filter, tuple):
             status_filter = tuple(status_filter)
-        backup = BackupInfo(self.server, backup_id=backup_id)
+        backup = LocalBackupInfo(self.server, backup_id=backup_id)
         available_backups = self.get_available_backups(
             status_filter + (backup.status,))
         ids = sorted(available_backups.keys())
@@ -374,10 +374,12 @@ class BackupManager(RemoteStatusMixin):
 
         return True
 
-    def backup(self):
+    def backup(self, wait=False, wait_timeout=None):
         """
         Performs a backup for the server
 
+        :param bool wait: wait for all the required WAL files to be archived
+        :param int|None wait_timeout:
         :return BackupInfo: the generated BackupInfo
         """
         _logger.debug("initialising backup information")
@@ -385,7 +387,7 @@ class BackupManager(RemoteStatusMixin):
         backup_info = None
         try:
             # Create the BackupInfo object representing the backup
-            backup_info = BackupInfo(
+            backup_info = LocalBackupInfo(
                 self.server,
                 backup_id=datetime.datetime.now().strftime('%Y%m%dT%H%M%S'))
             backup_info.save()
@@ -419,22 +421,22 @@ class BackupManager(RemoteStatusMixin):
         # KeyboardInterrupt (e.g.: CTRL-C)
         except BaseException as e:
             msg_lines = force_str(e).strip().splitlines()
+            # If the exception has no attached message use the raw
+            # type name
+            if len(msg_lines) == 0:
+                msg_lines = [type(e).__name__]
             if backup_info:
                 # Use only the first line of exception message
                 # in backup_info error field
                 backup_info.set_attribute("status", "FAILED")
-                # If the exception has no attached message use the raw
-                # type name
-                if len(msg_lines) == 0:
-                    msg_lines = [type(e).__name__]
                 backup_info.set_attribute(
                     "error",
                     "failure %s (%s)" % (
                         self.executor.current_action, msg_lines[0]))
 
-            output.error("Backup failed %s.\nDETAILS: %s\n%s",
-                         self.executor.current_action, msg_lines[0],
-                         '\n'.join(msg_lines[1:]))
+            output.error("Backup failed %s.\nDETAILS: %s",
+                         self.executor.current_action,
+                         '\n'.join(msg_lines))
 
         else:
             output.info("Backup end at LSN: %s (%s, %08X)",
@@ -451,6 +453,18 @@ class BackupManager(RemoteStatusMixin):
             # Create a restore point after a backup
             target_name = 'barman_%s' % backup_info.backup_id
             self.server.postgres.create_restore_point(target_name)
+
+            # If requested, wait for end_wal to be archived
+            if wait:
+                try:
+                    self.server.wait_for_wal(backup_info.end_wal, wait_timeout)
+                    self.check_backup(backup_info)
+                except KeyboardInterrupt:
+                    # Ignore CTRL-C pressed while waiting for WAL files
+                    output.info(
+                        "Got CTRL-C. Continuing without waiting for '%s' "
+                        "to be archived", backup_info.end_wal)
+
         finally:
             if backup_info:
                 backup_info.save()
@@ -485,7 +499,8 @@ class BackupManager(RemoteStatusMixin):
         """
         Performs a recovery of a backup
 
-        :param barman.infofile.BackupInfo backup_info: the backup to recover
+        :param barman.infofile.LocalBackupInfo backup_info: the backup
+            to recover
         :param str dest: the destination directory
         :param dict[str,str]|None tablespaces: a tablespace name -> location
             map (for relocation)
@@ -600,7 +615,7 @@ class BackupManager(RemoteStatusMixin):
         """
         Delete the basebackup dir of a given backup.
 
-        :param barman.infofile.BackupInfo backup: the backup to delete
+        :param barman.infofile.LocalBackupInfo backup: the backup to delete
         """
         backup_dir = backup.get_basebackup_directory()
         _logger.debug("Deleting base backup directory: %s" % backup_dir)
@@ -610,7 +625,7 @@ class BackupManager(RemoteStatusMixin):
         """
         Delete the data contained in a given backup.
 
-        :param barman.infofile.BackupInfo backup: the backup to delete
+        :param barman.infofile.LocalBackupInfo backup: the backup to delete
         """
         if backup.tablespaces:
             if backup.backup_version == 2:
@@ -638,14 +653,14 @@ class BackupManager(RemoteStatusMixin):
         """
 
         # Run the pre_wal_delete_script if present.
-        script = HookScriptRunner(self, 'wal_delete', 'pre')
+        script = HookScriptRunner(self, 'wal_delete_script', 'pre')
         script.env_from_wal_info(wal_info)
         script.run()
 
         # Run the pre_wal_delete_retry_script if present.
         retry_script = RetryHookScriptRunner(
             self, 'wal_delete_retry_script', 'pre')
-        script.env_from_wal_info(wal_info)
+        retry_script.env_from_wal_info(wal_info)
         retry_script.run()
 
         error = None
@@ -667,7 +682,7 @@ class BackupManager(RemoteStatusMixin):
         try:
             retry_script = RetryHookScriptRunner(
                 self, 'wal_delete_retry_script', 'post')
-            script.env_from_wal_info(wal_info, None, error)
+            retry_script.env_from_wal_info(wal_info, None, error)
             retry_script.run()
         except AbortedRetryHookScript as e:
             # Ignore the ABORT_STOP as it is a post-hook operation
@@ -677,7 +692,7 @@ class BackupManager(RemoteStatusMixin):
                             e.hook.exit_status, e.hook.script)
 
         # Run the post_wal_delete_script if present.
-        script = HookScriptRunner(self, 'wal_delete', 'post')
+        script = HookScriptRunner(self, 'wal_delete_script', 'post')
         script.env_from_wal_info(wal_info, None, error)
         script.run()
 
@@ -974,7 +989,7 @@ class BackupManager(RemoteStatusMixin):
         backup_id = self.get_last_backup_id()
         if backup_id:
             # Get the backup object
-            backup = BackupInfo(self.server, backup_id=backup_id)
+            backup = LocalBackupInfo(self.server, backup_id=backup_id)
             now = datetime.datetime.now(dateutil.tz.tzlocal())
             # Evaluate the point of validity
             validity_time = now - last_backup_maximum_age
@@ -998,7 +1013,7 @@ class BackupManager(RemoteStatusMixin):
         Also evaluate the deduplication ratio and the deduplicated size if
         applicable.
 
-        :param barman.infofile.BackupInfo backup_info: the backup to update
+        :param LocalBackupInfo backup_info: the backup to update
         """
         # Calculate the base backup size
         self.executor.current_action = "calculating backup size"
