@@ -46,6 +46,7 @@ from barman.exceptions import (CommandFailedException, DataTransferFailure,
                                PostgresIsInRecovery, SshCommandException)
 from barman.fs import UnixRemoteCommand
 from barman.infofile import BackupInfo
+from barman.postgres_plumbing import EXCLUDE_LIST, PGDATA_EXCLUDE_LIST
 from barman.remote_status import RemoteStatusMixin
 from barman.utils import (force_str, human_readable_timedelta, mkpath,
                           total_seconds, with_metaclass)
@@ -105,7 +106,7 @@ class BackupExecutor(with_metaclass(ABCMeta, RemoteStatusMixin)):
         """
         Perform a backup for the server - invoked by BackupManager.backup()
 
-        :param barman.infofile.BackupInfo backup_info: backup information
+        :param barman.infofile.LocalBackupInfo backup_info: backup information
         """
 
     def check(self, check_strategy):
@@ -138,7 +139,7 @@ class BackupExecutor(with_metaclass(ABCMeta, RemoteStatusMixin)):
         It the provided backup is the first, purge all WAL files before the
         backup start.
 
-        :param barman.infofile.BackupInfo backup_info: the backup to check
+        :param barman.infofile.LocalBackupInfo backup_info: the backup to check
         """
 
         # Do nothing if the begin_wal is not defined yet
@@ -166,7 +167,7 @@ class BackupExecutor(with_metaclass(ABCMeta, RemoteStatusMixin)):
         """
         Output message for backup start
 
-        :param barman.infofile.BackupInfo backup_info: backup information
+        :param barman.infofile.LocalBackupInfo backup_info: backup information
         """
         output.info("Copying files for %s", backup_info.backup_id)
 
@@ -174,7 +175,7 @@ class BackupExecutor(with_metaclass(ABCMeta, RemoteStatusMixin)):
         """
         Output message for backup end
 
-        :param barman.infofile.BackupInfo backup_info: backup information
+        :param barman.infofile.LocalBackupInfo backup_info: backup information
         """
         output.info("Copy done (time: %s)",
                     human_readable_timedelta(datetime.timedelta(
@@ -302,7 +303,7 @@ class PostgresBackupExecutor(BackupExecutor):
         The server must also be configured with enough max_wal_senders to leave
         at least one session available for the backup.
 
-        :param barman.infofile.BackupInfo backup_info: backup information
+        :param barman.infofile.LocalBackupInfo backup_info: backup information
         """
         try:
             # Set data directory and server version
@@ -498,7 +499,7 @@ class PostgresBackupExecutor(BackupExecutor):
         the method raises a DataTransferFailure, this trigger the retrying
         mechanism when necessary.
 
-        :param barman.infofile.BackupInfo backup_info: backup information
+        :param barman.infofile.LocalBackupInfo backup_info: backup information
         """
         # Make sure the destination directory exists, ensure the
         # right permissions to the destination dir
@@ -680,7 +681,7 @@ class SshBackupExecutor(with_metaclass(ABCMeta, BackupExecutor)):
         # Depending on the backup options value, create the proper strategy
         if BackupOptions.CONCURRENT_BACKUP in self.config.backup_options:
             # Concurrent backup strategy
-            self.strategy = ConcurrentBackupStrategy(self)
+            self.strategy = LocalConcurrentBackupStrategy(self)
         else:
             # Exclusive backup strategy
             self.strategy = ExclusiveBackupStrategy(self)
@@ -701,7 +702,7 @@ class SshBackupExecutor(with_metaclass(ABCMeta, BackupExecutor)):
         """
         Performs the actual copy of a backup for the server
 
-        :param barman.infofile.BackupInfo backup_info: backup information
+        :param barman.infofile.LocalBackupInfo backup_info: backup information
         """
 
     def backup(self, backup_info):
@@ -713,7 +714,7 @@ class SshBackupExecutor(with_metaclass(ABCMeta, BackupExecutor)):
         depends on both the specific class that derives from SshBackupExecutor
         and the selected strategy (e.g. exclusive backup through Rsync).
 
-        :param barman.infofile.BackupInfo backup_info: backup information
+        :param barman.infofile.LocalBackupInfo backup_info: backup information
         """
 
         # Start the backup, all the subsequent code must be wrapped in a
@@ -878,7 +879,7 @@ class SshBackupExecutor(with_metaclass(ABCMeta, BackupExecutor)):
                                 remote_status['last_archived_wal'] = name
                                 break
         except (PostgresConnectionError, FsOperationFailed) as e:
-            _logger.warn("Error retrieving PostgreSQL status: %s", e)
+            _logger.warning("Error retrieving PostgreSQL status: %s", e)
         return remote_status
 
     def _start_backup_copy_message(self, backup_info):
@@ -921,7 +922,7 @@ class PassiveBackupExecutor(BackupExecutor):
         """
         This method should never be called, because this is a passive server
 
-        :param barman.infofile.BackupInfo backup_info: backup information
+        :param barman.infofile.LocalBackupInfo backup_info: backup information
         """
         # The 'backup' command is not available on a passive node.
         # If we get here, there is a programming error
@@ -989,38 +990,6 @@ class RsyncBackupExecutor(SshBackupExecutor):
     from which it derives.
     """
 
-    PGDATA_EXCLUDE_LIST = [
-        # Exclude this to avoid log files copy
-        '/pg_log/*',
-        # Exclude this for (PostgreSQL < 10) to avoid WAL files copy
-        '/pg_xlog/*',
-        # This have been renamed on PostgreSQL 10
-        '/pg_wal/*',
-        # We handle this on a different step of the copy
-        '/global/pg_control',
-    ]
-
-    EXCLUDE_LIST = [
-        # Files: see excludeFiles const in PostgreSQL source
-        'pgsql_tmp*',
-        'postgresql.auto.conf.tmp',
-        'current_logfiles.tmp',
-        'pg_internal.init',
-        'postmaster.pid',
-        'postmaster.opts',
-        'recovery.conf',
-        'standby.signal',
-
-        # Directories: see excludeDirContents const in PostgreSQL source
-        'pg_dynshmem/*',
-        'pg_notify/*',
-        'pg_replslot/*',
-        'pg_serial/*',
-        'pg_stat_tmp/*',
-        'pg_snapshots/*',
-        'pg_subtrans/*',
-    ]
-
     def __init__(self, backup_manager):
         """
         Constructor
@@ -1040,7 +1009,7 @@ class RsyncBackupExecutor(SshBackupExecutor):
         the process.
         This method is the core of base backup copy using Rsync+Ssh.
 
-        :param barman.infofile.BackupInfo backup_info: backup information
+        :param barman.infofile.LocalBackupInfo backup_info: backup information
         """
 
         # Retrieve the previous backup metadata, then calculate safe_horizon
@@ -1082,13 +1051,13 @@ class RsyncBackupExecutor(SshBackupExecutor):
                 # If the tablespace location is inside the data directory,
                 # exclude and protect it from being copied twice during
                 # the data directory copy
-                if tablespace.location.startswith(backup_info.pgdata):
+                if tablespace.location.startswith(backup_info.pgdata + '/'):
                     exclude_and_protect += [
                         tablespace.location[len(backup_info.pgdata):]]
 
                 # Exclude and protect the tablespace from being copied again
                 # during the data directory copy
-                exclude_and_protect += ["pg_tblspc/%s" % tablespace.oid]
+                exclude_and_protect += ["/pg_tblspc/%s" % tablespace.oid]
 
                 # Make sure the destination directory exists in order for
                 # smart copy to detect that no file is present there
@@ -1109,7 +1078,7 @@ class RsyncBackupExecutor(SshBackupExecutor):
                     label=tablespace.name,
                     src=':%s/' % tablespace.location,
                     dst=tablespace_dest,
-                    exclude=['/*'] + self.EXCLUDE_LIST,
+                    exclude=['/*'] + EXCLUDE_LIST,
                     include=['/PG_%s_*' %
                              self.server.postgres.server_major_version],
                     bwlimit=self.config.get_bwlimit(tablespace),
@@ -1128,7 +1097,7 @@ class RsyncBackupExecutor(SshBackupExecutor):
             label='pgdata',
             src=':%s/' % backup_info.pgdata,
             dst=backup_dest,
-            exclude=self.PGDATA_EXCLUDE_LIST + self.EXCLUDE_LIST,
+            exclude=PGDATA_EXCLUDE_LIST + EXCLUDE_LIST,
             exclude_and_protect=exclude_and_protect,
             bwlimit=self.config.get_bwlimit(),
             reuse=self._reuse_path(previous_backup),
@@ -1210,8 +1179,8 @@ class RsyncBackupExecutor(SshBackupExecutor):
         the previous_backup otherwise it returns the path to the specified
         tablespace using it's oid.
 
-        :param barman.infofile.BackupInfo previous_backup_info: backup to be
-            reused
+        :param barman.infofile.LocalBackupInfo previous_backup_info: backup
+            to be reused
         :param barman.infofile.Tablespace tablespace: the tablespace to copy
         :returns: a string containing the local path with data to be reused
             or None
@@ -1240,14 +1209,14 @@ class BackupStrategy(with_metaclass(ABCMeta, object)):
     WAL_RE = re.compile(r'^START WAL LOCATION: (.*) \(file (.*)\)',
                         re.MULTILINE)
 
-    def __init__(self, executor, mode=None):
+    def __init__(self, postgres, mode=None):
         """
         Constructor
 
-        :param BackupExecutor executor: the BackupExecutor assigned
-            to the strategy
+        :param barman.postgres.PostgreSQLConnection postgres: the PostgreSQL
+            connection
         """
-        self.executor = executor
+        self.postgres = postgres
 
         # Holds the action being executed. Used for error messages.
         self.current_action = None
@@ -1271,7 +1240,7 @@ class BackupStrategy(with_metaclass(ABCMeta, object)):
         """
         Issue a stop of a backup - invoked by BackupExecutor.backup()
 
-        :param barman.infofile.BackupInfo backup_info: backup information
+        :param barman.infofile.LocalBackupInfo backup_info: backup information
         """
 
     @abstractmethod
@@ -1295,30 +1264,28 @@ class BackupStrategy(with_metaclass(ABCMeta, object)):
 
         :param barman.infofile.BackupInfo backup_info: backup information
         """
-        server = self.executor.server
-
         # Get the PostgreSQL data directory location
         self.current_action = 'detecting data directory'
         output.debug(self.current_action)
-        data_directory = server.postgres.get_setting('data_directory')
+        data_directory = self.postgres.get_setting('data_directory')
         backup_info.set_attribute('pgdata', data_directory)
 
         # Set server version
-        backup_info.set_attribute('version', server.postgres.server_version)
+        backup_info.set_attribute('version', self.postgres.server_version)
 
         # Set XLOG segment size
         backup_info.set_attribute('xlog_segment_size',
-                                  server.postgres.xlog_segment_size)
+                                  self.postgres.xlog_segment_size)
 
         # Set configuration files location
-        cf = server.postgres.get_configuration_files()
+        cf = self.postgres.get_configuration_files()
         for key in cf:
             backup_info.set_attribute(key, cf[key])
 
         # Get tablespaces information
         self.current_action = 'detecting tablespaces'
         output.debug(self.current_action)
-        tablespaces = server.postgres.get_tablespaces()
+        tablespaces = self.postgres.get_tablespaces()
         if tablespaces and len(tablespaces) > 0:
             backup_info.set_attribute('tablespaces', tablespaces)
             for item in tablespaces:
@@ -1330,7 +1297,8 @@ class BackupStrategy(with_metaclass(ABCMeta, object)):
         """
         Fill a backup info with information from a start_backup
 
-        :param barman.infofile.BackupInfo backup_info: object representing a
+        :param barman.infofile.BackupInfo backup_info: object
+        representing a
             backup
         :param DictCursor start_info: the result of the pg_start_backup
         command
@@ -1352,7 +1320,7 @@ class BackupStrategy(with_metaclass(ABCMeta, object)):
         # If file_name and file_offset are available, use them
         file_name = start_info.get('file_name')
         file_offset = start_info.get('file_offset')
-        if (file_name is not None and file_offset is not None):
+        if file_name is not None and file_offset is not None:
             backup_info.set_attribute('begin_wal',
                                       start_info['file_name'])
             backup_info.set_attribute('begin_offset',
@@ -1400,18 +1368,21 @@ class BackupStrategy(with_metaclass(ABCMeta, object)):
         """
         Fill a backup info with information from the backup_label file
 
-        :param barman.infofile.BackupInfo backup_info: object representing a
-            backup
+        :param barman.infofile.BackupInfo backup_info: object
+            representing a backup
         """
         # If backup_label is present in backup_info use it...
         if backup_info.backup_label:
             backup_label_data = backup_info.backup_label
         # ... otherwise load backup info from backup_label file
-        else:
+        elif hasattr(backup_info, 'get_data_directory'):
             backup_label_path = os.path.join(backup_info.get_data_directory(),
                                              'backup_label')
             with open(backup_label_path) as backup_label_file:
                 backup_label_data = backup_label_file.read()
+        else:
+            raise ValueError("Failure accessing backup_label for backup %s" %
+                             backup_info.backup_id)
 
         # Parse backup label
         wal_info = self.WAL_RE.search(backup_label_data)
@@ -1439,6 +1410,17 @@ class PostgresBackupStrategy(BackupStrategy):
     using pg_basebackup.
     """
 
+    def __init__(self, executor, *args, **kwargs):
+        """
+        Constructor
+
+        :param BackupExecutor executor: the BackupExecutor assigned
+            to the strategy
+        """
+        super(PostgresBackupStrategy, self).__init__(
+            executor.server.postgres, *args, **kwargs)
+        self.executor = executor
+
     def check(self, check_strategy):
         """
         Perform additional checks for the Postgres backup strategy
@@ -1452,7 +1434,7 @@ class PostgresBackupStrategy(BackupStrategy):
         backup executed using pg_basebackup to start, gathering information
         from postgres and filling the backup_info.
 
-        :param barman.infofile.BackupInfo backup_info: backup information
+        :param barman.infofile.LocalBackupInfo backup_info: backup information
         """
         self.current_action = "initialising postgres backup_method"
         super(PostgresBackupStrategy, self).start_backup(backup_info)
@@ -1471,7 +1453,7 @@ class PostgresBackupStrategy(BackupStrategy):
         during the start of a backup performed using rsync, are retrieved
         here
 
-        :param barman.infofile.BackupInfo backup_info: backup information
+        :param barman.infofile.LocalBackupInfo backup_info: backup information
         """
         self._backup_info_from_backup_label(backup_info)
 
@@ -1513,7 +1495,9 @@ class ExclusiveBackupStrategy(BackupStrategy):
         :param BackupExecutor executor: the BackupExecutor assigned
             to the strategy
         """
-        super(ExclusiveBackupStrategy, self).__init__(executor, 'exclusive')
+        super(ExclusiveBackupStrategy, self).__init__(
+            executor.server.postgres, 'exclusive')
+        self.executor = executor
         # Make sure that executor is of type SshBackupExecutor
         assert isinstance(executor, SshBackupExecutor)
         # Make sure that backup_options does not contain 'concurrent'
@@ -1528,7 +1512,7 @@ class ExclusiveBackupStrategy(BackupStrategy):
         exclusive physical backup to start, as well as preparing the
         information on the backup for Barman.
 
-        :param barman.infofile.BackupInfo backup_info: backup information
+        :param barman.infofile.LocalBackupInfo backup_info: backup information
         """
         super(ExclusiveBackupStrategy, self).start_backup(backup_info)
         label = "Barman backup %s %s" % (
@@ -1548,7 +1532,7 @@ class ExclusiveBackupStrategy(BackupStrategy):
         exclusive backup is finished, as well as preparing the information
         returned by PostgreSQL for Barman.
 
-        :param barman.infofile.BackupInfo backup_info: backup information
+        :param barman.infofile.LocalBackupInfo backup_info: backup information
         """
 
         self.current_action = "issuing stop backup command"
@@ -1580,54 +1564,46 @@ class ConcurrentBackupStrategy(BackupStrategy):
     """
     Concrete class for concurrent backup strategy.
 
-    This strategy is for SshBackupExecutor only and is responsible for
-    coordinating Barman with PostgreSQL on concurrent physical backup
-    operations through the pgespresso extension.
+    This strategy is responsible for coordinating Barman with PostgreSQL on
+    concurrent physical backup operations through concurrent backup
+    PostgreSQL api or the pgespresso extension.
     """
 
-    def __init__(self, executor):
+    def __init__(self, postgres):
         """
         Constructor
 
-        :param BackupExecutor executor: the BackupExecutor assigned
-            to the strategy
+        :param barman.postgres.PostgreSQLConnection postgres: the PostgreSQL
+            connection
         """
-        super(ConcurrentBackupStrategy, self).__init__(executor, 'concurrent')
-        # Make sure that executor is of type SshBackupExecutor
-        assert isinstance(executor, SshBackupExecutor)
-        # Make sure that backup_options contains 'concurrent'
-        assert (BackupOptions.CONCURRENT_BACKUP in
-                self.executor.config.backup_options)
+        super(ConcurrentBackupStrategy, self).__init__(postgres, 'concurrent')
 
-    # noinspection PyMethodMayBeStatic
-    def _write_backup_label(self, backup_info):
+    def check(self, check_strategy):
         """
-        Write backup_label file inside PGDATA folder
+        Perform additional checks for ConcurrentBackupStrategy
 
-        :param barman.infofile.BackupInfo  backup_info: tbackup information
+        :param CheckStrategy check_strategy: the strategy for the management
+             of the results of the various checks
         """
-        label_file = os.path.join(backup_info.get_data_directory(),
-                                  'backup_label')
-        output.debug("Writing backup label: %s" % label_file)
-        with open(label_file, 'w') as f:
-            f.write(backup_info.backup_label)
-
-    def _write_tablespace_map(self, backup_info):
-        """
-        Write tablespace_map file inside PGDATA folder
-
-        :param barman.infofile.BackupInfo  backup_info: backup information
-        """
-        map_file = os.path.join(backup_info.get_data_directory(),
-                                'tablespace_map')
-        output.debug("Writing tablespace map")
-        with open(map_file, 'w') as f:
-            for tbs in backup_info.tablespaces:
-                # In some cases (i.e. PostgreSQL on windows) a tablespace
-                # can contain a newline or a line feed. PostgreSQL
-                # pg_basebackup code does the same.
-                quoted_location = re.sub(r'([\n\r])', r'\\\1', tbs.location)
-                f.write('%s %s\n' % (tbs.oid, quoted_location))
+        check_strategy.init_check('pgespresso extension')
+        try:
+            # We execute this check only if the postgres connection is non None
+            # and the server version is lower than 9.6. On latest PostgreSQL
+            # there is a native API for concurrent backups.
+            if self.postgres and self.postgres.server_version < 90600:
+                if self.postgres.has_pgespresso:
+                    check_strategy.result(self.executor.config.name, True)
+                else:
+                    check_strategy.result(
+                        self.executor.config.name, False,
+                        hint='required for concurrent '
+                             'backups on PostgreSQL %s' %
+                             self.postgres.server_major_version)
+        except PostgresConnectionError:
+            # Skip the check if the postgres connection doesn't work.
+            # We assume that this error condition will be reported by
+            # another check.
+            pass
 
     def start_backup(self, backup_info):
         """
@@ -1643,7 +1619,7 @@ class ConcurrentBackupStrategy(BackupStrategy):
         label = "Barman backup %s %s" % (
             backup_info.server_name, backup_info.backup_id)
 
-        pg_version = self.executor.server.postgres.server_version
+        pg_version = self.postgres.server_version
         if pg_version >= 90600:
             # On 9.6+ execute native concurrent start backup
             _logger.debug("Start of native concurrent backup")
@@ -1659,7 +1635,7 @@ class ConcurrentBackupStrategy(BackupStrategy):
 
         :param barman.infofile.BackupInfo backup_info: backup information
         """
-        pg_version = self.executor.server.postgres.server_version
+        pg_version = self.postgres.server_version
         self.current_action = "issuing stop backup command"
         if pg_version >= 90600:
             # On 9.6+ execute native concurrent stop backup
@@ -1674,14 +1650,12 @@ class ConcurrentBackupStrategy(BackupStrategy):
 
         # Write backup_label retrieved from postgres connection
         self.current_action = "writing backup label"
-        self._write_backup_label(backup_info)
 
         # Ask PostgreSQL to switch to another WAL file. This is needed
         # to archive the transaction log file containing the backup
         # end position, which is required to recover from the backup.
-        postgres = self.executor.server.postgres
         try:
-            postgres.switch_wal()
+            self.postgres.switch_wal()
         except PostgresIsInRecovery:
             # Skip switching XLOG if a standby server
             pass
@@ -1692,9 +1666,8 @@ class ConcurrentBackupStrategy(BackupStrategy):
 
         :param barman.infofile.BackupInfo backup_info: backup information
         """
-        postgres = self.executor.server.postgres
         backup_info.set_attribute('status', "STARTED")
-        start_info = postgres.pgespresso_start_backup(label)
+        start_info = self.postgres.pgespresso_start_backup(label)
         backup_info.set_attribute('backup_label', start_info['backup_label'])
         self._backup_info_from_backup_label(backup_info)
 
@@ -1704,8 +1677,8 @@ class ConcurrentBackupStrategy(BackupStrategy):
 
         :param barman.infofile.BackupInfo backup_info: backup information
         """
-        postgres = self.executor.server.postgres
-        stop_info = postgres.pgespresso_stop_backup(backup_info.backup_label)
+        stop_info = self.postgres.pgespresso_stop_backup(
+            backup_info.backup_label)
         # Obtain a modifiable copy of stop_info object
         stop_info = stop_info.copy()
         # We don't know the exact backup stop location,
@@ -1714,33 +1687,6 @@ class ConcurrentBackupStrategy(BackupStrategy):
             stop_info['end_wal'], 0xFFFFFF)
         self._backup_info_from_stop_location(backup_info, stop_info)
 
-    def check(self, check_strategy):
-        """
-        Perform additional checks for ConcurrentBackupStrategy
-
-        :param CheckStrategy check_strategy: the strategy for the management
-             of the results of the various checks
-        """
-        check_strategy.init_check('pgespresso extension')
-        postgres = self.executor.server.postgres
-        try:
-            # We execute this check only if the postgres connection is non None
-            # and the server version is lower than 9.6. On latest PostgreSQL
-            # there is a native API for concurrent backups.
-            if postgres and postgres.server_version < 90600:
-                if postgres.has_pgespresso:
-                    check_strategy.result(self.executor.config.name, True)
-                else:
-                    check_strategy.result(self.executor.config.name, False,
-                                          hint='required for concurrent '
-                                               'backups on PostgreSQL %s' %
-                                               postgres.server_major_version)
-        except PostgresConnectionError:
-            # Skip the check if the postgres connection doesn't work.
-            # We assume that this error condition will be reported by
-            # another check.
-            pass
-
     def _concurrent_start_backup(self, backup_info, label):
         """
         Start a concurrent backup using the PostgreSQL 9.6
@@ -1749,9 +1695,8 @@ class ConcurrentBackupStrategy(BackupStrategy):
         :param barman.infofile.BackupInfo backup_info: backup information
         :param str label: the backup label
         """
-        postgres = self.executor.server.postgres
-        start_info = postgres.start_concurrent_backup(label)
-        postgres.allow_reconnect = False
+        start_info = self.postgres.start_concurrent_backup(label)
+        self.postgres.allow_reconnect = False
         self._backup_info_from_start_location(backup_info, start_info)
 
     def _concurrent_stop_backup(self, backup_info):
@@ -1761,8 +1706,55 @@ class ConcurrentBackupStrategy(BackupStrategy):
 
         :param barman.infofile.BackupInfo backup_info: backup information
         """
-        postgres = self.executor.server.postgres
-        stop_info = postgres.stop_concurrent_backup()
-        postgres.allow_reconnect = True
+        stop_info = self.postgres.stop_concurrent_backup()
+        self.postgres.allow_reconnect = True
         backup_info.set_attribute('backup_label', stop_info['backup_label'])
         self._backup_info_from_stop_location(backup_info, stop_info)
+
+
+class LocalConcurrentBackupStrategy(ConcurrentBackupStrategy):
+    """
+    Concrete class for concurrent backup strategy writing data locally.
+
+    This strategy is for SshBackupExecutor only and is responsible for
+    coordinating Barman with PostgreSQL on concurrent physical backup
+    operations through the pgespresso extension.
+    """
+
+    def __init__(self, executor):
+        """
+        Constructor
+
+        :param BackupExecutor executor: the BackupExecutor assigned
+            to the strategy
+        """
+        super(LocalConcurrentBackupStrategy, self).__init__(
+            executor.server.postgres)
+        self.executor = executor
+        # Make sure that executor is of type SshBackupExecutor
+        assert isinstance(executor, SshBackupExecutor)
+        # Make sure that backup_options contains 'concurrent'
+        assert (BackupOptions.CONCURRENT_BACKUP in
+                self.executor.config.backup_options)
+
+    # noinspection PyMethodMayBeStatic
+    def _write_backup_label(self, backup_info):
+        """
+        Write backup_label file inside PGDATA folder
+
+        :param barman.infofile.LocalBackupInfo  backup_info: backup information
+        """
+        label_file = os.path.join(backup_info.get_data_directory(),
+                                  'backup_label')
+        output.debug("Writing backup label: %s" % label_file)
+        with open(label_file, 'w') as f:
+            f.write(backup_info.backup_label)
+
+    def stop_backup(self, backup_info):
+        """
+        Stop backup wrapper
+
+        :param barman.infofile.LocalBackupInfo backup_info: backup information
+        """
+        super(LocalConcurrentBackupStrategy, self).stop_backup(backup_info)
+        self._write_backup_label(backup_info)
