@@ -36,50 +36,13 @@ from barman.config import RecoveryOptions
 from barman.exceptions import BadXlogSegmentName, RecoveryException, SyncError
 from barman.infofile import BackupInfo
 from barman.server import Server
-from barman.utils import (BarmanEncoder, configure_logging, drop_privileges,
-                          force_str, parse_log_level)
+from barman.utils import (BarmanEncoder, check_non_negative, check_positive,
+                          configure_logging, drop_privileges, force_str,
+                          parse_log_level)
 
 _logger = logging.getLogger(__name__)
 
 
-def check_non_negative(value):
-    """
-    Check for a positive integer option
-
-    :param value: str containing the value to check
-    """
-    if value is None:
-        return None
-    try:
-        int_value = int(value)
-    except Exception:
-        raise ArgumentTypeError("'%s' is not a valid non negative integer" %
-                                value)
-    if int_value < 0:
-        raise ArgumentTypeError("'%s' is not a valid non negative integer" %
-                                value)
-    return int_value
-
-
-def check_positive(value):
-    """
-    Check for a positive integer option
-
-    :param value: str containing the value to check
-    """
-    if value is None:
-        return None
-    try:
-        int_value = int(value)
-    except Exception:
-        raise ArgumentTypeError("'%s' is not a valid positive integer" %
-                                value)
-    if int_value < 1:
-        raise ArgumentTypeError("'%s' is not a valid positive integer" %
-                                value)
-    return int_value
-
-
 def check_target_action(value):
     """
     Check the target action option
@@ -113,7 +76,7 @@ def list_server(minimal=False):
         # we want all servers and the server cannot be None
 
         output.init('list_server', name, minimal=minimal)
-        description = server.config.description
+        description = server.config.description or ''
         # If the server has been manually disabled
         if not server.config.active:
             description += " (inactive)"
@@ -127,7 +90,10 @@ def list_server(minimal=False):
     output.close_and_exit()
 
 
-def cron():
+@arg('--keep-descriptors',
+     help='Keep the stdout and the stderr streams attached '
+          'to Barman subprocesses.')
+def cron(keep_descriptors=False):
     """
     Run maintenance tasks (global command)
     """
@@ -142,7 +108,7 @@ def cron():
         # but here we have only active and well configured servers.
 
         try:
-            server.cron()
+            server.cron(keep_descriptors=keep_descriptors)
         except Exception:
             # A cron should never raise an exception, so this code
             # should never be executed. However, it is here to protect
@@ -198,7 +164,7 @@ def backup_completer(prefix, parsed_args, **kwargs):
      action='store_true',
      default=SUPPRESS)
 @arg('--no-immediate-checkpoint',
-     help='forces the initial checkpoint to be spreaded',
+     help='forces the initial checkpoint to be spread',
      dest='immediate_checkpoint',
      action='store_false',
      default=SUPPRESS)
@@ -225,6 +191,18 @@ def backup_completer(prefix, parsed_args, **kwargs):
      metavar='KBPS',
      type=check_non_negative,
      default=SUPPRESS)
+@arg('--wait', '-w',
+     help='wait for all the required WAL files to be archived',
+     dest='wait',
+     action='store_true',
+     default=False)
+@arg('--wait-timeout',
+     help='the time, in seconds, spent waiting for the required '
+          'WAL files to be archived before timing out',
+     dest='wait_timeout',
+     metavar='TIMEOUT',
+     default=None,
+     type=check_non_negative)
 @expects_obj
 def backup(args):
     """
@@ -251,7 +229,7 @@ def backup(args):
         if hasattr(args, 'bwlimit'):
             server.config.bandwidth_limit = args.bwlimit
         with closing(server):
-            server.backup()
+            server.backup(wait=args.wait, wait_timeout=args.wait_timeout)
     output.close_and_exit()
 
 
@@ -848,6 +826,9 @@ def delete(args):
      help='put the retrieved WAL file in this directory '
           'with the original name',
      default=SUPPRESS)
+@arg('--partial', '-P',
+     help='retrieve also partial WAL files (.partial)',
+     action='store_true', dest='partial', default=False)
 @arg('--gzip', '-z', '-x',
      help='compress the output with gzip',
      action='store_const', const='gzip', dest='compression', default=SUPPRESS)
@@ -893,7 +874,8 @@ def get_wal(args):
         server.get_wal(args.wal_name,
                        compression=compression,
                        output_directory=output_directory,
-                       peek=peek)
+                       peek=peek,
+                       partial=args.partial)
     output.close_and_exit()
 
 
@@ -1063,7 +1045,8 @@ def global_config(args):
                       log_level or barman.config.DEFAULT_LOG_LEVEL,
                       config.log_format)
     if log_level is None:
-        _logger.warn('unknown log_level in config file: %s', config.log_level)
+        _logger.warning('unknown log_level in config file: %s',
+                        config.log_level)
 
     # Configure output
     if args.format != output.DEFAULT_WRITER or args.quiet or args.debug:
@@ -1176,7 +1159,7 @@ def get_server_list(args=None, skip_inactive=False, skip_disabled=False,
     :param bool skip_passive: skip passive servers when 'all' is required
     :param bool on_error_stop: stop if an error is found
     :param bool suppress_error: suppress display of errors (e.g. diagnose)
-    :rtype: dict(str,barman.server.Server|None)
+    :rtype: dict[str,Server]
     """
     server_dict = {}
 
@@ -1212,7 +1195,8 @@ def get_server_list(args=None, skip_inactive=False, skip_disabled=False,
             output.error("You cannot use 'all' with other server names")
         servers = available_servers
     else:
-        servers = args.server_name
+        # Put servers in a set, so multiple occurrences are counted only once
+        servers = set(args.server_name)
 
     # Loop through all the requested servers
     for server in servers:
@@ -1299,7 +1283,7 @@ def parse_backup_id(server, args):
 
     :param Server server: server object to search for the required backup
     :param args: command lien arguments namespace
-    :rtype: BackupInfo
+    :rtype: barman.infofile.LocalBackupInfo
     """
     if args.backup_id in ('latest', 'last'):
         backup_id = server.get_last_backup_id()
