@@ -1,4 +1,4 @@
-# Copyright (C) 2011-2017 2ndQuadrant Limited
+# Copyright (C) 2011-2018 2ndQuadrant Limited
 #
 # This file is part of Barman.
 #
@@ -52,7 +52,7 @@ class LockFile(object):
     """
 
     LOCK_PATTERN = None
-    """
+    r"""
     If defined in a subclass, it must be a compiled regular expression
     which matches the lock filename.
 
@@ -97,7 +97,7 @@ class LockFile(object):
         self.raise_if_fail = raise_if_fail
         self.wait = wait
 
-    def acquire(self, raise_if_fail=None, wait=None):
+    def acquire(self, raise_if_fail=None, wait=None, update_pid=True):
         """
         Creates and holds on to the lock file.
 
@@ -110,6 +110,7 @@ class LockFile(object):
 
         :param bool raise_if_fail: If True raise an exception on failure
         :param bool wait: If True issue a blocking request
+        :param bool update_pid: Whether to write our pid in the lockfile
         :returns bool: whether the lock has been acquired
         """
         if self.fd:
@@ -126,11 +127,12 @@ class LockFile(object):
             if not wait:
                 flags |= fcntl.LOCK_NB
             fcntl.flock(fd, flags)
-            # Once locked, replace the content of the file
-            os.lseek(fd, 0, os.SEEK_SET)
-            os.write(fd, ("%s\n" % os.getpid()).encode('ascii'))
-            # Truncate the file at the current position
-            os.ftruncate(fd, os.lseek(fd, 0, os.SEEK_CUR))
+            if update_pid:
+                # Once locked, replace the content of the file
+                os.lseek(fd, 0, os.SEEK_SET)
+                os.write(fd, ("%s\n" % os.getpid()).encode('ascii'))
+                # Truncate the file at the current position
+                os.ftruncate(fd, os.lseek(fd, 0, os.SEEK_CUR))
             self.fd = fd
             return True
         except (OSError, IOError) as e:
@@ -186,7 +188,7 @@ class LockFile(object):
         :raises LockFilePermissionDenied: when the lockfile is not accessible
         """
         try:
-            self.acquire(raise_if_fail=True, wait=False)
+            self.acquire(raise_if_fail=True, wait=False, update_pid=False)
         except LockFileBusy:
             try:
                 # Read the lock content and parse the PID
@@ -285,3 +287,48 @@ class ServerWalReceiveLock(LockFile):
         super(ServerWalReceiveLock, self).__init__(
             os.path.join(lock_directory, '.%s-receive-wal.lock' % server_name),
             raise_if_fail=True, wait=False)
+
+
+class ServerBackupIdLock(LockFile):
+    """
+    This lock protects from changing a backup that is in use.
+
+    Creates a '.<SERVER>-<BACKUP_ID>.lock' lock file under the given
+    lock_directory for a BACKUP of a SERVER.
+    """
+
+    def __init__(self, lock_directory, server_name, backup_id):
+        super(ServerBackupIdLock, self).__init__(
+            os.path.join(lock_directory, '.%s-%s.lock' % (
+                server_name, backup_id)),
+            raise_if_fail=True, wait=False)
+
+
+class ServerBackupSyncLock(LockFile):
+    """
+    This lock protects from multiple executions of the sync command on the same
+    backup.
+
+    Creates a '.<SERVER>-<BACKUP>-sync-backup.lock' lock file under the given
+    lock_directory for a BACKUP of a SERVER.
+    """
+
+    def __init__(self, lock_directory, server_name, backup_id):
+        super(ServerBackupSyncLock, self).__init__(
+            os.path.join(lock_directory, '.%s-%s-sync-backup.lock' % (
+                server_name, backup_id)),
+            raise_if_fail=True, wait=False)
+
+
+class ServerWalSyncLock(LockFile):
+    """
+    This lock protects from multiple executions of the sync-wal command
+
+    Creates a '.<SERVER>-sync-wal.lock' lock file under the given
+    lock_directory for the named SERVER.
+    """
+
+    def __init__(self, lock_directory, server_name):
+        super(ServerWalSyncLock, self).__init__(
+            os.path.join(lock_directory, '.%s-sync-wal.lock' % server_name),
+            raise_if_fail=True, wait=True)
