@@ -28,7 +28,8 @@ import logging
 import sys
 
 from barman.infofile import BackupInfo
-from barman.utils import BarmanEncoder, human_readable_timedelta, pretty_size
+from barman.utils import (BarmanEncoder, force_str, human_readable_timedelta,
+                          pretty_size, redact_passwords)
 from barman.xlog import diff_lsn
 
 __all__ = [
@@ -136,6 +137,9 @@ def _put(level, message, *args, **kwargs):
         global error_occurred
         error_occurred = True
         _writer.error_occurred()
+    # Make sure the message is an unicode string
+    if message:
+        message = force_str(message)
     # dispatch the call to the output handler
     getattr(_writer, level)(message, *args)
     # log the message as originating from caller's caller module
@@ -374,8 +378,9 @@ class ConsoleOutputWriter(object):
             message = '\n'
         else:
             message += '\n'
-        # Format and encode the message
-        encoded_msg = _format_message(message, args).encode('utf-8')
+        # Format and encode the message, redacting eventual passwords
+        encoded_msg = redact_passwords(
+            _format_message(message, args)).encode('utf-8')
         try:
             # Python 3.x
             stream.buffer.write(encoded_msg)
@@ -645,6 +650,8 @@ class ConsoleOutputWriter(object):
         data = dict(backup_ext_info)
         self.info("Backup %s:", data['backup_id'])
         self.info("  Server Name            : %s", data['server_name'])
+        if data['systemid']:
+            self.info("  System Id              : %s", data['systemid'])
         self.info("  Status                 : %s", data['status'])
         if data['status'] in BackupInfo.STATUS_COPY_DONE:
             self.info("  PostgreSQL Version     : %s", data['version'])
