@@ -40,6 +40,7 @@ from barman.exceptions import (ConninfoException, PostgresAppNameError,
                                PostgresSuperuserRequired,
                                PostgresUnsupportedFeature)
 from barman.infofile import Tablespace
+from barman.postgres_plumbing import function_name_map
 from barman.remote_status import RemoteStatusMixin
 from barman.utils import force_str, simplify_version, with_metaclass
 from barman.xlog import DEFAULT_XLOG_SEG_SIZE
@@ -69,7 +70,7 @@ def _atexit():
     """
     # Take a copy of the list because the conn.close() method modify it
     for conn in list(_live_connections):
-        _logger.warn(
+        _logger.warning(
             "Forcing %s cleanup during process shut down.",
             conn.__class__.__name__)
         conn.close()
@@ -82,16 +83,13 @@ class PostgreSQL(with_metaclass(ABCMeta, RemoteStatusMixin)):
 
     CHECK_QUERY = 'SELECT 1'
 
-    def __init__(self, config, conninfo):
+    def __init__(self, conninfo):
         """
         Abstract base class constructor for PostgreSQL interface.
 
-        :param barman.config.ServerConfig config: the server configuration
         :param str conninfo: Connection information (aka DSN)
         """
         super(PostgreSQL, self).__init__()
-        assert conninfo
-        self.config = config
         self.conninfo = conninfo
         self._conn = None
         self.allow_reconnect = True
@@ -177,6 +175,10 @@ class PostgreSQL(with_metaclass(ABCMeta, RemoteStatusMixin)):
             initial_status = self._conn.status
             cursor = self._conn.cursor()
             cursor.execute(self.CHECK_QUERY)
+            # Rollback if initial status was IDLE because the CHECK QUERY
+            # has started a new transaction.
+            if initial_status == STATUS_READY:
+                self._conn.rollback()
         except psycopg2.DatabaseError:
             # Connection is broken, so we need to reconnect
             self.close()
@@ -187,10 +189,6 @@ class PostgreSQL(with_metaclass(ABCMeta, RemoteStatusMixin)):
             return False
         finally:
             if cursor:
-                # Rollback if initial status was IDLE because the CHECK QUERY
-                # has started a new transaction.
-                if initial_status == STATUS_READY:
-                    self._conn.rollback()
                 cursor.close()
 
         return True
@@ -268,19 +266,14 @@ class StreamingConnection(PostgreSQL):
 
     CHECK_QUERY = 'IDENTIFY_SYSTEM'
 
-    def __init__(self, config):
+    def __init__(self, conninfo):
         """
         Streaming connection constructor
 
-        :param barman.config.ServerConfig config: the server configuration
+        :param str conninfo: Connection information (aka DSN)
         """
-        if config.streaming_conninfo is None:
-            raise ConninfoException(
-                "Missing 'streaming_conninfo' parameter for server '%s'"
-                % config.name)
+        super(StreamingConnection, self).__init__(conninfo)
 
-        super(StreamingConnection, self).__init__(config,
-                                                  config.streaming_conninfo)
         # Make sure we connect using the 'replication' option which
         # triggers streaming replication protocol communication
         self.conn_parameters['replication'] = 'true'
@@ -318,7 +311,7 @@ class StreamingConnection(PostgreSQL):
         """
         result = dict.fromkeys(
             ('connection_error', 'streaming_supported',
-                'streaming', 'systemid',
+                'streaming', 'streaming_systemid',
                 'timeline', 'xlogpos'),
             None)
         try:
@@ -339,7 +332,7 @@ class StreamingConnection(PostgreSQL):
             if row:
                 result['streaming'] = True
                 # IDENTIFY_SYSTEM always return at least two values
-                result['systemid'] = row[0]
+                result['streaming_systemid'] = row[0]
                 result['timeline'] = row[1]
                 # PostgreSQL 9.1+ returns also the current xlog flush location
                 if len(row) > 2:
@@ -349,8 +342,8 @@ class StreamingConnection(PostgreSQL):
             result['streaming'] = False
         except PostgresConnectionError as e:
             result['connection_error'] = force_str(e).strip()
-            _logger.warn("Error retrieving PostgreSQL status: %s",
-                         force_str(e).strip())
+            _logger.warning("Error retrieving PostgreSQL status: %s",
+                            force_str(e).strip())
         return result
 
     def create_physical_repslot(self, slot_name):
@@ -411,17 +404,20 @@ class PostgreSQLConnection(PostgreSQL):
     WALSTREAMER = 2
     ANY_STREAMING_CLIENT = (STANDBY, WALSTREAMER)
 
-    def __init__(self, config):
+    def __init__(self, conninfo, immediate_checkpoint=False, slot_name=None,
+                 application_name='barman'):
         """
         PostgreSQL connection constructor.
 
-        :param barman.config.ServerConfig config: the server configuration
+        :param str conninfo: Connection information (aka DSN)
+        :param bool immediate_checkpoint: Whether to do an immediate checkpoint
+           when start a backup
+        :param str|None slot_name: Replication slot name
         """
-        # Check that 'conninfo' option is properly set
-        if config.conninfo is None:
-            raise ConninfoException(
-                "Missing 'conninfo' parameter for server '%s'" % config.name)
-        super(PostgreSQLConnection, self).__init__(config, config.conninfo)
+        super(PostgreSQLConnection, self).__init__(conninfo)
+        self.immediate_checkpoint = immediate_checkpoint
+        self.slot_name = slot_name
+        self.application_name = application_name
         self.configuration_files = None
 
     def connect(self):
@@ -437,7 +433,9 @@ class PostgreSQLConnection(PostgreSQL):
         if server_version >= 90000 and not use_app_name:
             try:
                 cur = self._conn.cursor()
-                cur.execute('SET application_name TO barman')
+                # Do not use parameter substitution with SET
+                cur.execute('SET application_name TO %s' %
+                            self.application_name)
                 cur.close()
             # If psycopg2 fails to set the application name,
             # raise the appropriate exception
@@ -753,6 +751,7 @@ class PostgreSQLConnection(PostgreSQL):
             'replication_slot_support',
             'replication_slot',
             'synchronous_standby_names',
+            'postgres_systemid'
         ]
         # Initialise the result dictionary setting all the values to None
         result = dict.fromkeys(
@@ -788,7 +787,13 @@ class PostgreSQLConnection(PostgreSQL):
             result['is_in_recovery'] = self.is_in_recovery
             result['server_txt_version'] = self.server_txt_version
             result['pgespresso_installed'] = self.has_pgespresso
-            result['current_xlog'] = self.current_xlog_file_name
+            current_xlog_info = self.current_xlog_info
+            if current_xlog_info:
+                result['current_lsn'] = current_xlog_info['location']
+                result['current_xlog'] = current_xlog_info['file_name']
+            else:
+                result['current_lsn'] = None
+                result['current_xlog'] = None
             result['current_size'] = self.current_size
             result['archive_timeout'] = self.archive_timeout
             result['checkpoint_timeout'] = self.checkpoint_timeout
@@ -800,9 +805,9 @@ class PostgreSQLConnection(PostgreSQL):
             result["replication_slot_support"] = False
             if self.server_version >= 90400:
                 result["replication_slot_support"] = True
-                if self.config.slot_name is not None:
+                if self.slot_name is not None:
                     result["replication_slot"] = (
-                        self.get_replication_slot(self.config.slot_name))
+                        self.get_replication_slot(self.slot_name))
 
             # Retrieve the list of synchronous standby names
             result["synchronous_standby_names"] = []
@@ -810,11 +815,30 @@ class PostgreSQLConnection(PostgreSQL):
                 result["synchronous_standby_names"] = (
                     self.get_synchronous_standby_names())
 
+            if self.server_version >= 90600:
+                result["postgres_systemid"] = self.get_systemid()
         except (PostgresConnectionError, psycopg2.Error) as e:
-            _logger.warn("Error retrieving PostgreSQL status: %s",
-                         force_str(e).strip())
+            _logger.warning("Error retrieving PostgreSQL status: %s",
+                            force_str(e).strip())
         return result
 
+    def get_systemid(self):
+        """
+        Get a Postgres instance systemid
+        """
+        if self.server_version < 90600:
+            return
+
+        try:
+            cur = self._cursor()
+            cur.execute(
+                'SELECT system_identifier::text FROM pg_control_system()')
+            return cur.fetchone()[0]
+        except (PostgresConnectionError, psycopg2.Error) as e:
+            _logger.debug("Error retrieving PostgreSQL system Id: %s",
+                          force_str(e).strip())
+            return None
+
     def get_setting(self, name):
         """
         Get a Postgres setting with a given name
@@ -966,7 +990,7 @@ class PostgreSQLConnection(PostgreSQL):
                     "now() AS timestamp "
                     "FROM pg_start_backup(%s,%s) AS location"
                     .format(**self.name_map),
-                    (label, self.config.immediate_checkpoint))
+                    (label, self.immediate_checkpoint))
 
             start_row = cur.fetchone()
 
@@ -1009,7 +1033,7 @@ class PostgreSQLConnection(PostgreSQL):
                 "FROM pg_control_checkpoint()) AS timeline, "
                 "now() AS timestamp "
                 "FROM pg_start_backup(%s, %s, FALSE) AS location",
-                (label, self.config.immediate_checkpoint))
+                (label, self.immediate_checkpoint))
             start_row = cur.fetchone()
 
             # Rollback to release the transaction, as the connection
@@ -1126,7 +1150,7 @@ class PostgreSQLConnection(PostgreSQL):
             cur.execute(
                 'SELECT pgespresso_start_backup(%s,%s) AS backup_label, '
                 'now() AS timestamp',
-                (label, self.config.immediate_checkpoint))
+                (label, self.immediate_checkpoint))
 
             start_row = cur.fetchone()
 
@@ -1481,6 +1505,7 @@ class PostgreSQLConnection(PostgreSQL):
 
         :rtype: dict[str]
         """
+
         # Avoid raising an error if the connection is not available
         try:
             server_version = self.server_version
@@ -1489,33 +1514,4 @@ class PostgreSQLConnection(PostgreSQL):
                           'name_map will return names from latest version')
             server_version = None
 
-        if server_version and server_version < 100000:
-            return {
-                'pg_switch_wal': 'pg_switch_xlog',
-                'pg_walfile_name': 'pg_xlogfile_name',
-                'pg_wal': 'pg_xlog',
-                'pg_walfile_name_offset': 'pg_xlogfile_name_offset',
-                'pg_last_wal_replay_lsn': 'pg_last_xlog_replay_location',
-                'pg_current_wal_lsn': 'pg_current_xlog_location',
-                'pg_current_wal_insert_lsn': 'pg_current_xlog_insert_location',
-                'pg_last_wal_receive_lsn': 'pg_last_xlog_receive_location',
-                'sent_lsn': 'sent_location',
-                'write_lsn': 'write_location',
-                'flush_lsn': 'flush_location',
-                'replay_lsn': 'replay_location',
-            }
-
-        return {
-            'pg_switch_wal': 'pg_switch_wal',
-            'pg_walfile_name': 'pg_walfile_name',
-            'pg_wal': 'pg_wal',
-            'pg_walfile_name_offset': 'pg_walfile_name_offset',
-            'pg_last_wal_replay_lsn': 'pg_last_wal_replay_lsn',
-            'pg_current_wal_lsn': 'pg_current_wal_lsn',
-            'pg_current_wal_insert_lsn': 'pg_current_wal_insert_lsn',
-            'pg_last_wal_receive_lsn': 'pg_last_wal_receive_lsn',
-            'sent_lsn': 'sent_lsn',
-            'write_lsn': 'write_lsn',
-            'flush_lsn': 'flush_lsn',
-            'replay_lsn': 'replay_lsn',
-        }
+        return function_name_map(server_version)
