@@ -32,6 +32,7 @@ import pwd
 import re
 import signal
 import sys
+from argparse import ArgumentTypeError
 from contextlib import contextmanager
 
 from distutils.version import Version
@@ -102,7 +103,8 @@ def configure_logging(
         log_dir = os.path.dirname(log_file)
         try:
             mkpath(log_dir)
-            handler = logging.handlers.WatchedFileHandler(log_file)
+            handler = logging.handlers.WatchedFileHandler(
+                log_file, encoding='utf-8')
         except (OSError, IOError):
             # fallback to standard error
             warn = "Failed opening the requested log file. " \
@@ -467,3 +469,71 @@ def force_str(obj, encoding='utf-8', errors='replace'):
             # As last resort, use a repr call to avoid any exception
             obj = repr(obj)
     return obj
+
+
+def redact_passwords(text):
+    """
+    Redact passwords from the input text.
+
+    Password are found in these two forms:
+
+    Keyword/Value Connection Strings:
+    - host=localhost port=5432 dbname=mydb password=SHAME_ON_ME
+    Connection URIs:
+    - postgresql://[user[:password]][netloc][:port][/dbname]
+
+    :param str text: Input content
+    :return: String with passwords removed
+    """
+
+    # Remove passwords as found in key/value connection strings
+    text = re.sub(
+        "password=('(\\'|[^'])+'|[^ '\"]*)",
+        "password=*REDACTED*",
+        text)
+
+    # Remove passwords in connection URLs
+    text = re.sub(
+        r'(?<=postgresql:\/\/)([^ :@]+:)([^ :@]+)?@',
+        r'\1*REDACTED*@',
+        text)
+
+    return text
+
+
+def check_non_negative(value):
+    """
+    Check for a positive integer option
+
+    :param value: str containing the value to check
+    """
+    if value is None:
+        return None
+    try:
+        int_value = int(value)
+    except Exception:
+        raise ArgumentTypeError("'%s' is not a valid non negative integer" %
+                                value)
+    if int_value < 0:
+        raise ArgumentTypeError("'%s' is not a valid non negative integer" %
+                                value)
+    return int_value
+
+
+def check_positive(value):
+    """
+    Check for a positive integer option
+
+    :param value: str containing the value to check
+    """
+    if value is None:
+        return None
+    try:
+        int_value = int(value)
+    except Exception:
+        raise ArgumentTypeError("'%s' is not a valid positive integer" %
+                                value)
+    if int_value < 1:
+        raise ArgumentTypeError("'%s' is not a valid positive integer" %
+                                value)
+    return int_value
